<?php
/**
 * @file
 * Drush command to create a new theme based on the Mojo theme.
 *
 * Place this file in your ~/.drush directory.
 */

/**
 * Implements hook_drush_command().
 */
function mojo_drush_command() {
  $items = array();

  $items['mojo'] = array(
    'description' => 'Create a new theme based on the Mojo theme.',
    'arguments' => array(
      'name' => 'The name of your theme.',
    ),
    'options' => array(
      'description' => 'A short description of your theme.',
      'location' => 'The location of your theme in the sites directory. Defaults to "all" (sites/all/themes).',
      'machine_name' => 'The machine-readable name of your theme. This will be auto-generated from the human-readable name if omitted.',
      'enable' => 'Automatically enable this theme.',
      'set-default' => 'Automatically enable and set this theme as the default.',
    ),
    'examples' => array(
      'drush mojo "Theme Name"' => 'Creates a new theme called "Theme Name".',
      'drush mojo "Theme Name" --location=example.com' => 'Creates a new theme called "Theme Name" in sites/example.com/themes.',
    ),
  );

  return $items;
}

/**
 * Implements hook_drush_help().
 */
function mojo_drush_help($section) {
  switch ($section) {
    case 'drush:mojo':
      return dt('This command will create a new theme based on the Mojo theme.');
  }
}

/**
 * Implements drush_hook_COMMAND_validate().
 */
function drush_mojo_validate($name = NULL) {
  system_rebuild_theme_data();

  $themes = list_themes();
  $description = drush_get_option('description');
  $location = drush_get_option('location', 'all');
  $machine_name = drush_get_option('machine_name', _mojo_machine_name($name));

  drush_set_option('machine_name', $machine_name);

  if (!_mojo_theme_exists('mojo')) {
    return drush_set_error(
      'MOJO_ERROR',
      dt('Where is the Mojo theme? I could not find it.')
    );
  }

  if (!$machine_name || !preg_match('/^[a-z][a-z0-9_]*$/', $machine_name)) {
    return drush_set_error(
      'MOJO_ERROR',
      dt('The machine name was invalid or could not be generated properly. It must start with a letter and may only contain lowercase letters, numbers, and underscores.')
    );
  }

  if (_mojo_theme_exists($machine_name)) {
    return drush_set_error(
      'MOJO_ERROR',
      dt('A theme with that name already exists. The machine-readable name must be unique.')
    );
  }

  if (!in_array($location, mojo_sites())) {
    return drush_set_error(
      'MOJO_ERROR',
      dt('The location is invalid.')
    );
  }
}

/**
 * Converts $name to a machine-readable format.
 */
function _mojo_machine_name($name) {
  $name = preg_replace('/^[^a-z]+/', '', strtolower($name));
  $name = preg_replace('/[^a-z0-9_]+/', '_', $name);
  $name = str_replace('__', '_', $name);
  $name = trim($name, '_');

  return $name;
}

/**
 * Checks if $theme_name already exists in Drupal.
 */
function _mojo_theme_exists($theme_name) {
  $themes = list_themes();

  return isset($themes[$theme_name]);
}

/**
 * Returns an array of available Drupal sites.
 */
function mojo_sites() {
  $sites = &drupal_static(__FUNCTION__);

  if (!isset($sites)) {
    $sites = array();

    if (file_exists(DRUPAL_ROOT . '/sites/sites.php')) {
      include(DRUPAL_ROOT . '/sites/sites.php');
    }

    $sites = array('all') + array_values($sites);
  }

  return $sites;
}

/**
 * Implements drush_hook_COMMAND().
 */
function drush_mojo($name = NULL) {
  if (!isset($name)) {
    $name = drush_get_option('name');
  }

  $machine_name = drush_get_option('machine_name', _mojo_machine_name($name));
  $drupal_root = drush_locate_root();
  $mojo_path = $drupal_root . '/' . drupal_get_path('theme', 'mojo');
  $theme_path = $drupal_root . '/sites/' . drush_get_option('location', 'all') . '/themes/' . $machine_name;
  $description = drush_get_option('description');
  $info_file = $theme_path . '/' . $machine_name . '.info';

  $set_default = drush_get_option('set-default') !== NULL;
  $enable = $set_default || drush_get_option('enable') !== NULL;

  // Copy the Mojo theme directory recursively to the new theme's location.
  drush_op('mojo_copy', $mojo_path, $theme_path);

  // Rename the .info file.
   drush_op('rename', $theme_path . '/mojo.info', $info_file);

  // Update the .info file based on the command options.
  $changes = array(
    '= Mojo' => '= ' . $name,
    'A <a href="http://futurefriend.ly/">future friendly</a> starter theme using front-end best practices.' => $description,
  );
  drush_op('mojo_file_str_replace', $info_file, array_keys($changes), $changes);

  // Replace all occurrences of 'mojo' with the machine name of the new theme.
  drush_op('mojo_file_str_replace', $theme_path . '/theme-settings.php', 'mojo', $machine_name);
  drush_op('mojo_file_str_replace', $theme_path . '/template.php', 'mojo', $machine_name);
  drush_op('mojo_file_str_replace', $theme_path . '/inc/process.inc', 'mojo', $machine_name);
  drush_op('mojo_file_str_replace', $theme_path . '/inc/theme.inc', 'mojo', $machine_name);
  drush_op('mojo_file_str_replace', $theme_path . '/js/script.js', 'mojo', $machine_name);
  drush_op('mojo_file_str_replace', $theme_path . '/panels/layouts/flexgrid/flexgrid.inc', 'mojo', $machine_name);

  // Notify user of the newly created theme.
  drush_print(dt(
    'The "!name" theme has been created in: !path',
    array(
      '!name' => $name,
      '!path' => $theme_path,
    )
  ));
}

/**
 * Copy a directory recursively.
 */
function mojo_copy($source_dir, $target_dir, $ignore = '/^(\.(\.)?|CVS|\.svn|\.git|\.DS_Store)$/') {
  if (!is_dir($source_dir)) {
    drush_die(dt('The directory "!directory" was not found.', array('!directory' => $source_dir)));
  }
  $dir = opendir($source_dir);
  @mkdir($target_dir);
  while ($file = readdir($dir)) {
    if (!preg_match($ignore, $file)) {
      if (is_dir($source_dir . '/' . $file)) {
        mojo_copy($source_dir . '/' . $file, $target_dir . '/' . $file, $ignore);
      }
      else {
        copy($source_dir . '/' . $file, $target_dir . '/' . $file);
      }
    }
  }
  closedir($dir);
}

/**
 * Replace strings in a file.
 */
function mojo_file_str_replace($file_path, $find, $replace) {
  $file_contents = file_get_contents($file_path);
  $file_contents = str_replace($find, $replace, $file_contents);
  file_put_contents($file_path, $file_contents);
}
