<?php
/**
 * @file
 * Preprocess and process functions.
 */

/**
 * Override or insert variables into the maintenance page template.
 */
function mojo_preprocess_maintenance_page(&$vars) {
  // While markup for normal pages is split into page.tpl.php and html.tpl.php,
  // the markup for the maintenance page is all in the single
  // maintenance-page.tpl.php template. So, to have what's done in
  // mojo_preprocess_html() also happen on the maintenance page, it has to be
  // called here.
  mojo_preprocess_html($vars);
}

/**
 * Override or insert variables into the html template.
 */
function mojo_preprocess_html(&$vars) {
  // Modify RDF output.
  $vars['rdf'] = new stdClass();
  if (module_exists('rdf') && isset($vars['rdf_namespaces'])) {
    $vars['doctype'] = '<!DOCTYPE html PUBLIC "-//W3C//DTD HTML+RDFa 1.1//EN">' . "\n";
    $vars['rdf']->version = ' version="HTML+RDFa 1.1"';
    $vars['rdf']->namespaces = $vars['rdf_namespaces'];
    $vars['rdf']->profile = ' profile="' . $vars['grddl_profile'] . '"';
  }
  else {
    $vars['doctype'] = '<!DOCTYPE html>' . "\n";
    $vars['rdf']->version = '';
    $vars['rdf']->namespaces = '';
    $vars['rdf']->profile = '';
  }

  // Add HTML5 Shiv if not using Modernizr.
  $vars['shiv'] = '<!--[if lt IE 9]><script src="' . base_path() . drupal_get_path('theme', $GLOBALS['theme_key']) . '/js/html5.js"></script><![endif]-->';
  if (module_exists('modernizr')) {
    $vars['shiv'] = '';
  }

  // Add Selectivizr.
  $vars['selectivizr'] = '';
  if (theme_get_setting('use_selectivizr')) {
    $vars['selectivizr'] = '<!--[if (lt IE 9) & (!IEMobile)]><script src="http://cdnjs.cloudflare.com/ajax/libs/selectivizr/1.0.2/selectivizr-min.js"></script><![endif]-->';
  }

  // Urge IE6 users to upgrade.
  $vars['warn_ie6'] = '';
  if (theme_get_setting('warn_ie6')) {
    $vars['warn_ie6'] = '<!--[if lt IE 7]><p class="ie6-warning">Your browser is <em>ancient!</em> <a href="http://browsehappy.com/">Upgrade to a different browser</a> or <a href="http://www.google.com/chromeframe/?redirect=true">install Google Chrome Frame</a> to experience this site.</p><![endif]-->';
  }

  // Add language body class.
  if (function_exists('locale')) {
    $vars['classes_array'][] = 'lang-' . $vars['language']->language;
  }

  // Add body classes for each page and section.
  if (!$vars['is_front']) {
    $path = drupal_get_path_alias($_GET['q']);
    list($section,) = explode('/', $path, 2);
    if (arg(0) == 'node') {
      if (arg(1) == 'add') {
        $section = 'page-node-add';
      }
      elseif (is_numeric(arg(1)) && (arg(2) == 'edit' || arg(2) == 'delete')) {
        $section = 'page-node-' . arg(2);
      }
    }
    $vars['classes_array'][] = drupal_html_class('section-' . $section);
  }

  // Remove uneccessary page-node- body class.
  $remove_key = array_search('page-node-', $vars['classes_array']);
  if (!is_null($remove_key)) {
    unset($vars['classes_array'][$remove_key]);
  }
}

/**
 * Override or insert variables into the node template.
 */
function mojo_preprocess_node(&$vars) {
  $vars['classes_array'][] = 'clearfix';
  $vars['attributes_array']['role'][] = 'article';
  $vars['title_attributes_array']['class'][] = 'article-title';
  $vars['content_attributes_array']['class'][] = 'article-content';
  $vars['datetime'] = format_date($vars['created'], 'custom', 'c');
  $vars['date'] = format_date($vars['created'], 'custom', 'F j, Y');
  if (variable_get('node_submitted_' . $vars['node']->type, TRUE)) {
    $vars['submitted'] = t('!datetime by !username',
      array(
        '!datetime' => '<time class="node-date" datetime="' . $vars['datetime'] . '" pubdate="pubdate">' . $vars['date'] . '</time>',
        '!username' => $vars['name'],
      )
    );
  }
  else {
    $vars['submitted'] = '';
  }
  $vars['unpublished'] = '';
  if (!$vars['status']) {
    $vars['unpublished'] = '<div class="unpublished">' . t('Unpublished') . '</div>';
  }
}

/**
 * Override or insert variables into the region template.
 */
function mojo_preprocess_region(&$vars) {
  // Remove region class.
  array_shift($vars['classes_array']);

  // Remove classes from main content region.
  if ($vars['region'] == 'content') {
    $vars['classes_array'] = array();
  }

  // Add region-sidebar class to sidebar regions.
  if ($vars['region'] == 'sidebar_first' || $vars['region'] == 'sidebar_second') {
    $vars['classes_array'][] = 'region-sidebar';
  }
}

/**
 * Override or insert variables into the comment template.
 */
function mojo_preprocess_comment(&$vars) {
  $vars['classes_array'][] = 'clearfix';
  $vars['title_attributes_array']['class'][] = 'comment-title';
  $vars['content_attributes_array']['class'][] = 'content';
  $vars['content_attributes_array']['class'][] = 'comment-content';
  $vars['datetime'] = format_date($vars['comment']->created, 'custom', 'c');
  $vars['date'] = format_date($vars['comment']->created, 'custom', 'F j, Y g:i a');
  $vars['created'] = '<time class="comment-date" datetime="' . $vars['datetime'] . '" pubdate="pubdate">' . $vars['date'] . '</time>';
  $vars['unpublished'] = '';
  if ($vars['status'] == 'comment-unpublished') {
    $vars['unpublished'] = '<div class="unpublished">' . t('Unpublished') . '</div>';
  }
}

/**
 * Override or insert variables into the field template.
 */
function mojo_preprocess_field(&$vars) {
  $vars['title_attributes_array']['class'][] = 'field-label';
  $vars['content_attributes_array']['class'][] = 'field-items';

  // Edit classes for taxonomy term reference fields.
  if ($vars['field_type_css'] == 'taxonomy-term-reference') {
    $vars['content_attributes_array']['class'][] = 'comma-separated';
  }
}

/**
 * Override or insert variables into the aggregator feed item template.
 */
function mojo_preprocess_aggregator_item(&$vars) {
  $item = $vars['item'];
  $vars['datetime'] = format_date($item->timestamp, 'custom', 'c');
}

/**
 * Change the search form to use the "search" input element of HTML5.
 */
function mojo_preprocess_search_block_form(&$vars) {
  $vars['search_form'] = str_replace('type="text"', 'type="search"', $vars['search_form']);
}

/**
 * Override or insert variables into the menu link theme function.
 */
function mojo_preprocess_menu_link(&$vars) {
  $menu = $vars['element']['#original_link']['menu_name'];
  $mlid = $vars['element']['#original_link']['mlid'];
  $item_classes = &$vars['element']['#attributes']['class'];
  $link_classes = &$vars['element']['#localized_options']['attributes']['class'];

  // Remove uneccessary item classes.
  $remove = array(
    'first',
    'last',
    'leaf',
  );
  foreach ($remove as $val) {
    $remove_key = array_search($val, $item_classes);
    if (!is_null($remove_key)) {
      unset($item_classes[$remove_key]);
    }
  }

  // Add global classes to all menu links.
  $item_classes[] = 'menu-item';
  $link_classes[] = 'menu-link';
}

/**
 * Override or insert variables into the views list template.
 */
function mojo_preprocess_views_view_list(&$vars) {
  // Only use custom row classes.
  $vars['classes_array'][0] = $vars['options']['row_class'];
}
